==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/SliceClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SliceClickEventArgsDescription } from "./SliceClickEventArgsDescription";
/**
 * @hidden
 */
var SliceClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SliceClickEventArgsDescriptionMetadata, _super);
    function SliceClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SliceClickEventArgsDescriptionMetadata.b = function (a) {
        if (SliceClickEventArgsDescriptionMetadata.a == null) {
            SliceClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SliceClickEventArgsDescriptionMetadata.c(SliceClickEventArgsDescriptionMetadata.a);
        }
        if (a.g(SliceClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(SliceClickEventArgsDescriptionMetadata.a);
    };
    SliceClickEventArgsDescriptionMetadata.c = function (a) {
        a.item("IsSelected", "Boolean");
        a.item("IsExploded", "Boolean");
        a.item("OriginalEventRef", "(w:OriginalEvent,wf:OriginalEvent)DataRef");
    };
    SliceClickEventArgsDescriptionMetadata.d = function (a) {
        SliceClickEventArgsDescriptionMetadata.b(a);
        a.u("SliceClickEventArgs", function () { return new SliceClickEventArgsDescription(); });
        a.t("SliceClickEventArgs", SliceClickEventArgsDescriptionMetadata.a);
    };
    SliceClickEventArgsDescriptionMetadata.$t = markType(SliceClickEventArgsDescriptionMetadata, 'SliceClickEventArgsDescriptionMetadata');
    SliceClickEventArgsDescriptionMetadata.a = null;
    return SliceClickEventArgsDescriptionMetadata;
}(Base));
export { SliceClickEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/SliceClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SliceClickEventArgsDescription } from "./SliceClickEventArgsDescription";
/**
 * @hidden
 */
var SliceClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SliceClickEventArgsDescriptionMetadata, _super);
    function SliceClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SliceClickEventArgsDescriptionMetadata.b = function (a) {
        if (SliceClickEventArgsDescriptionMetadata.a == null) {
            SliceClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SliceClickEventArgsDescriptionMetadata.c(SliceClickEventArgsDescriptionMetadata.a);
        }
        if (a.j(SliceClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(SliceClickEventArgsDescriptionMetadata.a);
    };
    SliceClickEventArgsDescriptionMetadata.c = function (a) {
        a.item("IsSelected", "Boolean");
        a.item("IsExploded", "Boolean");
        a.item("OriginalEventRef", "(w:OriginalEvent,wf:OriginalEvent)DataRef");
    };
    SliceClickEventArgsDescriptionMetadata.d = function (a) {
        SliceClickEventArgsDescriptionMetadata.b(a);
        a.aa("SliceClickEventArgs", function () { return new SliceClickEventArgsDescription(); });
        a.z("SliceClickEventArgs", SliceClickEventArgsDescriptionMetadata.a);
    };
    SliceClickEventArgsDescriptionMetadata.$t = markType(SliceClickEventArgsDescriptionMetadata, 'SliceClickEventArgsDescriptionMetadata');
    SliceClickEventArgsDescriptionMetadata.a = null;
    return SliceClickEventArgsDescriptionMetadata;
}(Base));
export { SliceClickEventArgsDescriptionMetadata };
